@@ -222,6 +222,6 @@ class APScheduler(object):
         self.app.add_url_rule('/scheduler/jobs/<job_id>', 'get_job', views.get_job)
         self.app.add_url_rule('/scheduler/jobs/<job_id>', 'delete_job', views.delete_job, methods=['DELETE'])
         self.app.add_url_rule('/scheduler/jobs/<job_id>', 'update_job', views.update_job, methods=['PATCH'])
-        self.app.add_url_rule('/scheduler/jobs/<job_id>/pause', 'pause_job', views.pause_job)
-        self.app.add_url_rule('/scheduler/jobs/<job_id>/resume', 'resume_job', views.resume_job)
-        self.app.add_url_rule('/scheduler/jobs/<job_id>/run', 'run_job', views.run_job)
+        self.app.add_url_rule('/scheduler/jobs/<job_id>/pause', 'pause_job', views.pause_job, methods=['POST'])
+        self.app.add_url_rule('/scheduler/jobs/<job_id>/resume', 'resume_job', views.resume_job, methods=['POST'])
+        self.app.add_url_rule('/scheduler/jobs/<job_id>/run', 'run_job', views.run_job, methods=['POST'])
